eric6/QScintilla/Editor.py

changeset 7960
e8fc383322f7
parent 7923
91e843545d9a
child 7969
62eff8b34a8d
--- a/eric6/QScintilla/Editor.py	Tue Jan 05 18:28:31 2021 +0100
+++ b/eric6/QScintilla/Editor.py	Wed Jan 06 13:47:01 2021 +0100
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing the editor component of the eric6 IDE.
+Module implementing the editor component of the eric IDE.
 """
 
 import os
@@ -46,7 +46,7 @@
 
 class Editor(QsciScintillaCompat):
     """
     Class implementing the editor component of the eric6 IDE.
     
     @signal modificationStatusChanged(bool, QsciScintillaCompat) emitted when
         the modification status has changed
@@ -6991,7 +6991,7 @@
             else:
                 msg = self.tr(
                     """<p>The file <b>{0}</b> has been changed while it"""
                     """ was opened in eric6. Reread it?</p>"""
                 ).format(self.fileName)
                 yesDefault = True
                 if self.isModified():
@@ -46,7 +46,7 @@
 class Editor(QsciScintillaCompat):
     """
-    Class implementing the editor component of the eric6 IDE.
+    Class implementing the editor component of the eric IDE.
     
     @signal modificationStatusChanged(bool, QsciScintillaCompat) emitted when
@@ -6991,7 +6991,7 @@
                 msg = self.tr(
                     """<p>The file <b>{0}</b> has been changed while it"""
-                    """ was opened in eric6. Reread it?</p>"""
+                    """ was opened in eric. Reread it?</p>"""
                 ).format(self.fileName)
                 yesDefault = True

eric ide

mercurial